@@ -35,7 +35,7 @@
 #include <libgnomeprint/gnome-print-config.h>
 
 #include "gnome-print-i18n.h"
-#include "gnome-printer-dialog.h"
+#include "gnome-printer-selector.h"
 #include "gnome-print-paper-selector.h"
 #include "gnome-print-copies.h"
 #include "gnome-print-dialog.h"
@@ -294,18 +294,12 @@ gnome_print_dialog_construct (GnomePrintDialog *gpd, const guchar *title, gint f
 	
 		gtk_container_add (GTK_CONTAINER (GTK_DIALOG (gpd)->vbox), gpd->notebook);
 		
-		/* Add the job page, if it will have any content */
-		/* FIXME: We should just hide it, in case the app wants to append something
-		 * we do this to work around bug #81600 in gtk+ (Chema)
-		 */
-		if (flags) {
-			gpd->job = gpd_create_job_page (gpd);
-			gtk_container_set_border_width (GTK_CONTAINER (gpd->job), 4);
-			gtk_widget_show (gpd->job);
-			l = gtk_label_new_with_mnemonic (_("Job"));
-			gtk_widget_show (l);
-			gtk_notebook_append_page (GTK_NOTEBOOK (gpd->notebook), gpd->job, l);
-		}
+		/* Add the job page, if it has any content */
+		gpd->job = gpd_create_job_page (gpd);
+		gtk_container_set_border_width (GTK_CONTAINER (gpd->job), 4);
+		l = gtk_label_new_with_mnemonic (_("Job"));
+		gtk_widget_show (l);
+		gtk_notebook_append_page (GTK_NOTEBOOK (gpd->notebook), gpd->job, l);
 		
 		/* Add the printers page */
 		hb = gtk_hbox_new (FALSE, 0);
@@ -315,7 +309,7 @@ gnome_print_dialog_construct (GnomePrintDialog *gpd, const guchar *title, gint f
 		gtk_container_set_border_width (GTK_CONTAINER (hb), 4);
 		gtk_widget_show (gpd->printer);
 		
-		gtk_box_pack_start (GTK_BOX (hb), gpd->printer, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (hb), gpd->printer, TRUE, TRUE, 0);
 		
 		l = gtk_label_new_with_mnemonic (_("Printer"));
 		gtk_widget_show (l);
@@ -361,15 +355,19 @@ gnome_print_dialog_construct (GnomePrintDialog *gpd, const guchar *title, gint f
 	if (flags & GNOME_PRINT_DIALOG_RANGE) {
 		GtkWidget *r;
 		r = g_object_get_data (G_OBJECT (gpd->job), "range");
-		if (r)
+		if (r) {
 			gtk_widget_show (r);
+			gtk_widget_show (gpd->job);
+		}
 	}
 
 	if (flags & GNOME_PRINT_DIALOG_COPIES) {
 		GtkWidget *c;
 		c = g_object_get_data (G_OBJECT (gpd->job), "copies");
-		if (c)
+		if (c) {
 			gtk_widget_show (c);
+			gtk_widget_show (gpd->job);
+		}
 	}
 }
 
